@@ -23,6 +23,7 @@ public:
     void _append(Magick::Image);
     void _appendImages(Magick::Image*);
     void _coalesceImages(void);
+    void _flattenImages(Magick::Image*);
     void _readImages(const std::string&);
     void _readImages(Magick::Blob&);
     void _writeImages(const std::string&, bool);
@@ -80,6 +81,11 @@ void _ImageList::_coalesceImages(void)
     Magick::coalesceImages(&_images, _images.begin(), _images.end());
 }
 
+void _ImageList::_flattenImages(Magick::Image *_image)
+{
+    Magick::flattenImages(_image, _images.begin(), _images.end());
+}
+
 void _ImageList::_readImages(const std::string &imageSpec)
 {
     Magick::readImages(&_images, imageSpec);
@@ -113,11 +119,12 @@ void __STL()
 {
     class_< _ImageList >("ImageList", init< >())
         .def("__len__", &_ImageList::_length)
-	.def("__getitem__", (Magick::Image (_ImageList::*)(const unsigned int))&_ImageList::_get)
-	.def("__iter__", range(&_ImageList::_begin, &_ImageList::_end))
+        .def("__getitem__", (Magick::Image (_ImageList::*)(const unsigned int))&_ImageList::_get)
+        .def("__iter__", range(&_ImageList::_begin, &_ImageList::_end))
         .def("append", (void (_ImageList::*)(Magick::Image))&_ImageList::_append)
         .def("appendImages", (void (_ImageList::*)(Magick::Image*))&_ImageList::_appendImages)
         .def("coalesceImags", (void (_ImageList::*)(void))&_ImageList::_coalesceImages)
+        .def("flattenImags", (void (_ImageList::*)(void))&_ImageList::_flattenImages)
         .def("readImages", (void (_ImageList::*)(const std::string&))&_ImageList::_readImages)
         .def("readImages", (void (_ImageList::*)(Magick::Blob&))&_ImageList::_readImages)
         .def("writeImages", (void (_ImageList::*)(const std::string&, bool))&_ImageList::_writeImages, Magick_ImageList__writeImages_overloads_1_2())
